<template>
  <div class="float-panel">
    <i class="horn horn-br"></i>
    <i class="horn horn-bl"></i>
    <div class="head title-border">
      <div class="title-text-border">
        <div class="title-icon"></div>
        <div class="title-text">业务看板</div>
        <div class="title-button" :class="{'switch-head-up':true, 'switch-head-down': !panelSwitch.main}"
             @click="switchPanel">
          <!-- <i class="el-icon-arrow-down"></i> -->
        </div>
      </div>
    </div>
    <div class="body-box" id="panelContent">
      <div id="panelInnerContent" :style="{ height:height }">
        <slot></slot>
      </div>
    </div>
  </div>
</template>

<script>
import '@assets/css/map/magic.min.css'
import presets from './layerControllerPresets'

import iconSetting from '@/assets/images/map-pages/icon/setting.png'

export default {
  name: 'LayerController',
  components: {},
  props: {
    preset: {
      type: String,
      default: 'default'
    }
  },
  computed: {
    map () {
      return this.$store.state.map.map
    },
    L () {
      return this.$store.state.map.L
    },
    layerHelper () {
      return this.$store.state.map.layerHelper
    },
    layerControllerVisible () {
      return this.$store.state.map.layerControllerVisible
    }
  },
  data () {
    return {
      height: '200px',
      icons: {
        setting: iconSetting
      },
      panelSwitch: {
        main: true // 主窗口
      }
    }
  },
  mounted () {
    this.$nextTick(function () {
      this.init()
    })
  },
  methods: {
    init () {
      this.initPreset()
    },
    initPreset () {
      if (this.preset !== 'default') {
        const prmPreset = presets[this.preset]
        Object.assign(this.layerControllerVisible, prmPreset) // 防止预设参数与默认参数不一致导致报错，如果没有按照您的配置发生改变，请检查拼写是否正确
        if (prmPreset === 'undefined') {
          console.log('该图层控制面板的预设没有找到，请检查预设名称是否正确！')
        } else {
          this.$store.commit('updateLayerControllerVisible', this.layerControllerVisible)
        }
      }
    },
    switchPanel () {
      this.panelSwitch.main = !this.panelSwitch.main
      if (this.panelSwitch.main) {
        this.height = '200px'
      } else {
        this.height = '0px'
      }
    }
  }
}
</script>

<style lang="less">

.float-panel {
  position: absolute;
  left: 10px;
  bottom: 10px;
  width: 230px;
  height: auto;
  font-size: 11px;
  z-index: 1000;

  div {
    color: #90c8e0;
  }

  #panelInnerContent {
    overflow: hidden;
    transition: all 0.5s linear;
  }

  .title-border {
    width: 100%;
    height: 28px;
    background: #10488c;
    -webkit-clip-path: polygon(0px 0px, 0px 28px, 230px 28px, 230px 9px, 95px 9px, 86px 0px);
    clip-path: polygon(0px 0px, 0px 28px, 230px 28px, 230px 9px, 95px 9px, 86px 0px);
    position: relative;
  }

  .title-border:before {
    content: "";
    display: block;
    position: absolute;
    width: 6px;
    height: 6px;
    top: 0;
    left: 0;
    background-color: #38c8ef;
  }

  .title-border:after {
    content: "";
    display: block;
    position: absolute;
    width: 6px;
    height: 6px;
    top: 9px;
    right: 0;
    background-color: #38c8ef;
    -webkit-clip-path: polygon(0px 0px, 0px 1px, 5px 1px, 5px 6px, 6px 6px, 6px 0px);
    clip-path: polygon(0px 0px, 0px 1px, 5px 1px, 5px 6px, 6px 6px, 6px 0px);
  }

  .title-text-border {
    width: 100%;
    height: 28px;
    background: #091331;
    -webkit-clip-path: polygon(1px 1px, 1px 27px, 229px 27px, 229px 10px, 94px 10px, 85px 1px);
    clip-path: polygon(1px 1px, 1px 27px, 229px 27px, 229px 10px, 94px 10px, 85px 1px);
  }

  .title-icon {
    float: left;
    width: 22px;
    height: 22px;
    margin-top: 4px;
    margin-left: 2px;
    background-image: url(/assets/images/map-pages/icon/setting.png);
  }

  .title-text {
    float: left;
    width: 150px;
    color: #00d0f9;
    margin-left: 4px;
    line-height: 20px;
    font-weight: bold;
    margin-top: 6px;
    text-align: left;
    filter: brightness(100%);
    text-shadow: 0 0 5px #00d0f9, 0 0 0 #00d0f9, 0 0 0 #00d0f9, 0 0 0 #0258c5, 0 0 0 #0258c5, 0 0 2px #0258c5, 0 0 5px #0258c5, 0 0 15px #0258c5;
  }

  .title-line {
    display: inline-block;
    width: 120px;
    height: 1px;
    // margin-top: 14px;
    margin-left: 4px;
    background-color: #04527f;
    line-height: 5px;
    vertical-align: middle;
  }

  .title-point {
    display: inline-block;
    width: 5px;
    height: 5px;
    // margin-top: 12px;
    background-color: #04527f;
    line-height: 5px;
    vertical-align: middle;
  }

  .title-button {
    float: right;
    width: 28px;
    height: 28px;
    cursor: pointer;

    :hover {
      font-weight: bold;
      color: white;
    }
  }

  .body-box {
    background-color: rgba(44, 62, 80, 0.6);
    border: 1px solid #10488c;
    margin-top: -1px;
    height: auto;
  }

  .switch-head-up {
    width: 22px;
    height: 16px;
    float: right;
    margin-top: 10px;
    margin-right: 10px;
    cursor: pointer;
    background-image: url(/assets/images/map-pages/icon/xljt1.png);
    transform: rotateX(0deg);
    transform-origin: 50% 50%;
    transition: transform 0.5s linear 0s;
  }

  .switch-head-down {
    transform: rotateX(180deg);
    transform-origin: 50% 50%;
    transition: transform 0.5s linear 0s;
  }

  select {
    background: transparent;
    margin: 6px;
    border: .5px solid #569EB7;
    width: 150px;
    color: #569EB7;
    padding: 0 16px;
  }

  .horn {
    width: 6px;
    height: 6px;
    float: left;
    position: absolute;
  }

  .horn-tl {
    background-image: url(/assets/images/map-pages/cosmetics/horn_tl.png) center center no-repeat;
    left: -1px;
    top: -1px;
  }

  .horn-tr {
    background-image: url(/assets/images/map-pages/cosmetics/horn_tr.png) center center no-repeat;
    right: -1px;
    top: -1px;
  }

  .horn-bl {
    background-image: url(/assets/images/map-pages/cosmetics/horn_bl.png) center center no-repeat;
    left: -1px;
    bottom: -1px;
  }

  .horn-br {
    background-image: url(/assets/images/map-pages/cosmetics/horn_br.png) center center no-repeat;
    right: -1px;
    bottom: -1px;
  }

  ::-webkit-scrollbar {
    width: 7px;
    height: 5px !important;
  }

  ::-webkit-scrollbar-thumb {
    /*滚动条里面小方块*/
    border-radius: 10px;
    box-shadow: inset 0 0 5px rgba(0, 0, 0, 0.2);
    background: #0661AE;
    border: 1px solid transparent;
  }

  ::-webkit-scrollbar-track {
    /*滚动条里面轨道*/
    // box-shadow   : inset 0 0 5px rgba(0, 0, 0, 0.2);
    border-radius: 0px;
    background: #0E3565;
  }
}

</style>
